==> onegov.org-0.0.7.tar.gz: onegov.org-0.0.7/onegov/org/initial_content.py <==
import codecs
import os
import textwrap

from datetime import datetime, timedelta
from onegov.core.utils import module_path
from onegov.event import EventCollection
from onegov.form import FormCollection
from onegov.libres import ResourceCollection
from onegov.page import PageCollection
from onegov.org.models import Organisation
from sedate import as_datetime


def create_new_organisation(app, name):

    org = Organisation(name=name)
    org.homepage_structure = textwrap.dedent("""
        <row>
            <column span="8">
                <homepage-cover />
                <news />
            </column>
            <column span="4">
                <panel>
                    <links title="Dienstleistungen">
                        <link url="./formulare"
                            description="Anfragen &amp; Rückmeldungen">
                            Formulare
                        </link>
                        <link url="./ressourcen"
                            description="Räume &amp; Tageskarten">
                            Reservationen
                        </link>
                    </links>
                </panel>
                <panel>
                    <events />
                </panel>
                <panel>
                    <links title="Verzeichnisse">
                        <link url="./personen"
                            description="Alle Kontakte">
                            Personen
                        </link>
                        <link url="./fotoalben"
                            description="Impressionen">
                            Fotoalben
                        </link>
                        <link url="./a-z"
                            description="Kataolg A-Z">
                            Themen
                        </link>
                    </links>
                </panel>
            </column>
        </row>
    """)

    session = app.session()
    session.add(org)

    add_root_pages(session)
    add_builtin_forms(session)
    add_events(session, name)
    add_resources(app.libres_context)


def add_root_pages(session):
    pages = PageCollection(session)

    pages.add_root(
        "Organisation",
        name='organisation',
        type='topic',
        meta={'trait': 'page'}
    )
    pages.add_root(
        "Themen",
        name='themen',
        type='topic',
        meta={'trait': 'page'}
    )
    pages.add_root(
        "Kontakt",
        name='kontakt',
        type='topic',
        meta={'trait': 'page'}
    )
    pages.add_root(
        "Aktuelles",
        name='aktuelles',
        type='news',
        meta={'trait': 'news'}
    )


def add_builtin_forms(session, definitions=None):
    forms = FormCollection(session).definitions
    definitions = definitions or builtin_form_definitions()

    for name, title, definition in definitions:
        if not forms.by_name(name):
            form = forms.add(
                name=name,
                title=title,
                definition=definition,
                type='custom'
            )

        assert form.form_class().has_required_email_field, (
            "Each form must have at least one required email field"
        )


def builtin_form_definitions(path=None):
    """ Yields the name, title and the form definition of all form definitions
    in the given or the default path.

    """
    path = path or module_path('onegov.org', 'forms/builtin')

    for filename in os.listdir(path):
        if filename.endswith('.form'):
            name = filename.replace('.form', '')
            title, definition = load_definition(os.path.join(path, filename))
            yield name, title, definition


def load_definition(path):
    """ Loads the title and the form definition from the given file. """

    with codecs.open(path, 'r', encoding='utf-8') as formfile:
        formlines = formfile.readlines()

        title = formlines[0].strip()
        definition = ''.join(formlines[3:])

        return title, definition


def add_resources(libres_context):
    resource = ResourceCollection(libres_context)
    resource.add(
        "Tageskarte",
        'Europe/Zurich',
        type='daypass',
        name='tageskarte'
    )
    resource.add(
        "Konferenzraum",
        'Europe/Zurich',
        type='room',
        name='konferenzraum'
    )


def add_events(session, name):
    start = as_datetime(datetime.today().date())

    while start.weekday() != 6:
        start = start + timedelta(days=1)

    events = EventCollection(session)
    event = events.add(
        title="150 Jahre {}".format(name),
        start=start + timedelta(hours=11, minutes=0),
        end=start + timedelta(hours=22, minutes=0),
        timezone="Europe/Zurich",
        tags=["Party"],
        location="Sportanlage",
        content={
            "description": "Wir feiern das 150 jährige Bestehen.",
            "organizer": name
        },
        meta={"submitter_email": "info@example.org"},
    )
    event.submit()
    event.publish()
    event = events.add(
        title="Generalversammlung",
        start=start + timedelta(days=2, hours=20, minutes=0),
        end=start + timedelta(days=2, hours=22, minutes=30),
        timezone="Europe/Zurich",
        tags=["Politics"],
        location="Gemeindesaal",
        content={
            "description": "Alle Jahre wieder.",
            "organizer": name
        },
        meta={"submitter_email": "info@example.org"},
    )
    event.submit()
    event.publish()
    event = events.add(
        title="Gemeinsames Turnen",
        start=start + timedelta(days=2, hours=10, minutes=0),
        end=start + timedelta(days=2, hours=11, minutes=0),
        recurrence=(
            "RRULE:FREQ=WEEKLY;WKST=MO;BYDAY=TU,TH;UNTIL={0}".format(
                (start + timedelta(days=31)).strftime('%Y%m%dT%H%M%SZ')
            )
        ),
        timezone="Europe/Zurich",
        tags=["Sports"],
        location="Turnhalle",
        content={
            "description": "Gemeinsam fit werden.",
            "organizer": "Frauenverein"
        },
        meta={"submitter_email": "info@example.org"},
    )
    event.submit()
    event.publish()
    event = events.add(
        title="Grümpelturnier",
        start=start + timedelta(days=7, hours=10, minutes=0),
        end=start + timedelta(days=7, hours=18, minutes=0),
        timezone="Europe/Zurich",
        tags=["Sports"],
        location="Sportanlage",
        content={
            "description": "Bolzen auf dem Platz.",
            "organizer": "Sportverein"
        },
        meta={"submitter_email": "info@example.org"},
    )
    event.submit()
    event.publish()

==> onegov.org-0.3.0.tar.gz: onegov.org-0.3.0/onegov/org/initial_content.py <==
import codecs
import os
import yaml

from datetime import datetime, timedelta
from onegov.core.utils import module_path
from onegov.event import EventCollection
from onegov.file import FileSetCollection, FileCollection
from onegov.form import FormCollection
from onegov.libres import ResourceCollection
from onegov.org.models import Organisation
from onegov.page import PageCollection
from sedate import as_datetime
from functools import lru_cache


@lru_cache(maxsize=1)
def load_content(path):
    with open(path, 'r') as f:
        return yaml.load(f)


def absolute_path(path, base):
    if path.startswith('/'):
        return path
    if path.startswith('~'):
        return os.path.expanduser(path)

    return os.path.join(base, path)


def create_new_organisation(app, name, create_files=True, path=None):
    path = path or module_path('onegov.org', 'content/de.yaml')
    content = load_content(path)

    org = Organisation(name=name, **content['organisation'])

    session = app.session()
    session.add(org)

    add_pages(session, path)
    add_builtin_forms(session)
    add_events(session, name)
    add_resources(app.libres_context)

    if create_files:
        add_filesets(session, name, path)

    return org


def add_pages(session, path):
    pages = PageCollection(session)

    for ix, page in enumerate(load_content(path).get('pages')):
        if 'parent' in page:
            parent = pages.by_path(page['parent'])
        else:
            parent = None

        pages.add(
            parent=parent,
            title=page['title'],
            type=page['type'],
            name=page.get('name', None),
            meta=page.get('meta', None),
            content=page.get('content', None),
            order=ix
        )


def add_builtin_forms(session, definitions=None):
    forms = FormCollection(session).definitions
    definitions = definitions or builtin_form_definitions()

    for name, title, definition in definitions:
        if not forms.by_name(name):
            form = forms.add(
                name=name,
                title=title,
                definition=definition,
                type='custom'
            )

        assert form.form_class().has_required_email_field, (
            "Each form must have at least one required email field"
        )


def builtin_form_definitions(path=None):
    """ Yields the name, title and the form definition of all form definitions
    in the given or the default path.

    """
    path = path or module_path('onegov.org', 'forms/builtin')

    for filename in os.listdir(path):
        if filename.endswith('.form'):
            name = filename.replace('.form', '')
            title, definition = load_definition(os.path.join(path, filename))
            yield name, title, definition


def load_definition(path):
    """ Loads the title and the form definition from the given file. """

    with codecs.open(path, 'r', encoding='utf-8') as formfile:
        formlines = formfile.readlines()

        title = formlines[0].strip()
        definition = ''.join(formlines[3:])

        return title, definition


def add_resources(libres_context):
    resource = ResourceCollection(libres_context)
    resource.add(
        "Tageskarte",
        'Europe/Zurich',
        type='daypass',
        name='tageskarte'
    )
    resource.add(
        "Konferenzraum",
        'Europe/Zurich',
        type='room',
        name='konferenzraum'
    )


def add_filesets(session, organisation_name, path):
    base = os.path.dirname(path)

    for fileset in load_content(path).get('filesets', tuple()):

        fs = FileSetCollection(session, fileset['type']).add(
            title=fileset['title'],
            meta=fileset.get('meta', None),
            content=fileset.get('content', None)
        )

        files = FileCollection(session, fileset['type'])

        for file in fileset.get('files'):
            filepath = absolute_path(file['path'], base)

            with open(filepath, 'rb') as f:

                fs.files.append(
                    files.add(
                        filename=os.path.basename(file['path']),
                        content=f,
                        note=file.get('note', '').format(
                            organisation=organisation_name
                        )
                    )
                )


def add_events(session, name):
    start = as_datetime(datetime.today().date())

    while start.weekday() != 6:
        start = start + timedelta(days=1)

    events = EventCollection(session)
    event = events.add(
        title="150 Jahre {}".format(name),
        start=start + timedelta(hours=11, minutes=0),
        end=start + timedelta(hours=22, minutes=0),
        timezone="Europe/Zurich",
        tags=["Party"],
        location="Sportanlage",
        content={
            "description": "Wir feiern das 150 jährige Bestehen.",
            "organizer": name
        },
        meta={"submitter_email": "info@example.org"},
    )
    event.submit()
    event.publish()
    event = events.add(
        title="Generalversammlung",
        start=start + timedelta(days=2, hours=20, minutes=0),
        end=start + timedelta(days=2, hours=22, minutes=30),
        timezone="Europe/Zurich",
        tags=["Politics"],
        location="Gemeindesaal",
        content={
            "description": "Alle Jahre wieder.",
            "organizer": name
        },
        meta={"submitter_email": "info@example.org"},
    )
    event.submit()
    event.publish()
    event = events.add(
        title="Gemeinsames Turnen",
        start=start + timedelta(days=2, hours=10, minutes=0),
        end=start + timedelta(days=2, hours=11, minutes=0),
        recurrence=(
            "RRULE:FREQ=WEEKLY;WKST=MO;BYDAY=TU,TH;UNTIL={0}".format(
                (start + timedelta(days=31)).strftime('%Y%m%dT%H%M%SZ')
            )
        ),
        timezone="Europe/Zurich",
        tags=["Sports"],
        location="Turnhalle",
        content={
            "description": "Gemeinsam fit werden.",
            "organizer": "Frauenverein"
        },
        meta={"submitter_email": "info@example.org"},
    )
    event.submit()
    event.publish()
    event = events.add(
        title="Grümpelturnier",
        start=start + timedelta(days=7, hours=10, minutes=0),
        end=start + timedelta(days=7, hours=18, minutes=0),
        timezone="Europe/Zurich",
        tags=["Sports"],
        location="Sportanlage",
        content={
            "description": "Bolzen auf dem Platz.",
            "organizer": "Sportverein"
        },
        meta={"submitter_email": "info@example.org"},
    )
    event.submit()
    event.publish()
